@@ -14,8 +14,6 @@ class MigrateOperation(object):
 
     This system is part of the operation extensibility API.
 
-    .. versionadded:: 0.8.0
-
     .. seealso::
 
         :ref:`operation_objects`
@@ -78,21 +76,16 @@ class DropConstraintOp(MigrateOperation):
         table_name,
         type_=None,
         schema=None,
-        _orig_constraint=None,
+        _reverse=None,
     ):
         self.constraint_name = constraint_name
         self.table_name = table_name
         self.constraint_type = type_
         self.schema = schema
-        self._orig_constraint = _orig_constraint
+        self._reverse = _reverse
 
     def reverse(self):
-        if self._orig_constraint is None:
-            raise ValueError(
-                "operation is not reversible; "
-                "original constraint is not present"
-            )
-        return AddConstraintOp.from_constraint(self._orig_constraint)
+        return AddConstraintOp.from_constraint(self.to_constraint())
 
     def to_diff_tuple(self):
         if self.constraint_type == "foreignkey":
@@ -117,12 +110,19 @@ class DropConstraintOp(MigrateOperation):
             constraint_table.name,
             schema=constraint_table.schema,
             type_=types[constraint.__visit_name__],
-            _orig_constraint=constraint,
+            _reverse=AddConstraintOp.from_constraint(constraint),
         )
 
     def to_constraint(self):
-        if self._orig_constraint is not None:
-            return self._orig_constraint
+
+        if self._reverse is not None:
+            constraint = self._reverse.to_constraint()
+            constraint.name = self.constraint_name
+            constraint_table = sqla_compat._table_for_constraint(constraint)
+            constraint_table.name = self.table_name
+            constraint_table.schema = self.schema
+
+            return constraint
         else:
             raise ValueError(
                 "constraint cannot be produced; "
@@ -130,7 +130,6 @@ class DropConstraintOp(MigrateOperation):
             )
 
     @classmethod
-    @util._with_legacy_names([("type", "type_"), ("name", "constraint_name")])
     def drop_constraint(
         cls, operations, constraint_name, table_name, type_=None, schema=None
     ):
@@ -145,14 +144,6 @@ class DropConstraintOp(MigrateOperation):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-
         """
 
         op = cls(constraint_name, table_name, type_=type_, schema=schema)
@@ -170,11 +161,6 @@ class DropConstraintOp(MigrateOperation):
 
             :meth:`.Operations.drop_constraint`
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-
         """
         op = cls(
             constraint_name,
@@ -196,49 +182,36 @@ class CreatePrimaryKeyOp(AddConstraintOp):
     constraint_type = "primarykey"
 
     def __init__(
-        self,
-        constraint_name,
-        table_name,
-        columns,
-        schema=None,
-        _orig_constraint=None,
-        **kw
+        self, constraint_name, table_name, columns, schema=None, **kw
     ):
         self.constraint_name = constraint_name
         self.table_name = table_name
         self.columns = columns
         self.schema = schema
-        self._orig_constraint = _orig_constraint
         self.kw = kw
 
     @classmethod
     def from_constraint(cls, constraint):
         constraint_table = sqla_compat._table_for_constraint(constraint)
-
         return cls(
             constraint.name,
             constraint_table.name,
-            constraint.columns,
+            constraint.columns.keys(),
             schema=constraint_table.schema,
-            _orig_constraint=constraint,
+            **constraint.dialect_kwargs
         )
 
     def to_constraint(self, migration_context=None):
-        if self._orig_constraint is not None:
-            return self._orig_constraint
-
         schema_obj = schemaobj.SchemaObjects(migration_context)
         return schema_obj.primary_key_constraint(
             self.constraint_name,
             self.table_name,
             self.columns,
             schema=self.schema,
+            **self.kw
         )
 
     @classmethod
-    @util._with_legacy_names(
-        [("name", "constraint_name"), ("cols", "columns")]
-    )
     def create_primary_key(
         cls, operations, constraint_name, table_name, columns, schema=None
     ):
@@ -277,15 +250,6 @@ class CreatePrimaryKeyOp(AddConstraintOp):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-           * cols -> columns
-
         """
         op = cls(constraint_name, table_name, columns, schema)
         return operations.invoke(op)
@@ -323,19 +287,12 @@ class CreateUniqueConstraintOp(AddConstraintOp):
     constraint_type = "unique"
 
     def __init__(
-        self,
-        constraint_name,
-        table_name,
-        columns,
-        schema=None,
-        _orig_constraint=None,
-        **kw
+        self, constraint_name, table_name, columns, schema=None, **kw
     ):
         self.constraint_name = constraint_name
         self.table_name = table_name
         self.columns = columns
         self.schema = schema
-        self._orig_constraint = _orig_constraint
         self.kw = kw
 
     @classmethod
@@ -347,20 +304,16 @@ class CreateUniqueConstraintOp(AddConstraintOp):
             kw["deferrable"] = constraint.deferrable
         if constraint.initially:
             kw["initially"] = constraint.initially
-
+        kw.update(constraint.dialect_kwargs)
         return cls(
             constraint.name,
             constraint_table.name,
             [c.name for c in constraint.columns],
             schema=constraint_table.schema,
-            _orig_constraint=constraint,
             **kw
         )
 
     def to_constraint(self, migration_context=None):
-        if self._orig_constraint is not None:
-            return self._orig_constraint
-
         schema_obj = schemaobj.SchemaObjects(migration_context)
         return schema_obj.unique_constraint(
             self.constraint_name,
@@ -371,13 +324,6 @@ class CreateUniqueConstraintOp(AddConstraintOp):
         )
 
     @classmethod
-    @util._with_legacy_names(
-        [
-            ("name", "constraint_name"),
-            ("source", "table_name"),
-            ("local_cols", "columns"),
-        ]
-    )
     def create_unique_constraint(
         cls,
         operations,
@@ -423,23 +369,12 @@ class CreateUniqueConstraintOp(AddConstraintOp):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-           * source -> table_name
-           * local_cols -> columns
-
         """
 
         op = cls(constraint_name, table_name, columns, schema=schema, **kw)
         return operations.invoke(op)
 
     @classmethod
-    @util._with_legacy_names([("name", "constraint_name")])
     def batch_create_unique_constraint(
         cls, operations, constraint_name, columns, **kw
     ):
@@ -453,11 +388,6 @@ class CreateUniqueConstraintOp(AddConstraintOp):
 
             :meth:`.Operations.create_unique_constraint`
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-
         """
         kw["schema"] = operations.impl.schema
         op = cls(constraint_name, operations.impl.table_name, columns, **kw)
@@ -481,7 +411,6 @@ class CreateForeignKeyOp(AddConstraintOp):
         referent_table,
         local_cols,
         remote_cols,
-        _orig_constraint=None,
         **kw
     ):
         self.constraint_name = constraint_name
@@ -489,7 +418,6 @@ class CreateForeignKeyOp(AddConstraintOp):
         self.referent_table = referent_table
         self.local_cols = local_cols
         self.remote_cols = remote_cols
-        self._orig_constraint = _orig_constraint
         self.kw = kw
 
     def to_diff_tuple(self):
@@ -524,20 +452,17 @@ class CreateForeignKeyOp(AddConstraintOp):
 
         kw["source_schema"] = source_schema
         kw["referent_schema"] = target_schema
-
+        kw.update(constraint.dialect_kwargs)
         return cls(
             constraint.name,
             source_table,
             target_table,
             source_columns,
             target_columns,
-            _orig_constraint=constraint,
             **kw
         )
 
     def to_constraint(self, migration_context=None):
-        if self._orig_constraint is not None:
-            return self._orig_constraint
         schema_obj = schemaobj.SchemaObjects(migration_context)
         return schema_obj.foreign_key_constraint(
             self.constraint_name,
@@ -549,13 +474,6 @@ class CreateForeignKeyOp(AddConstraintOp):
         )
 
     @classmethod
-    @util._with_legacy_names(
-        [
-            ("name", "constraint_name"),
-            ("source", "source_table"),
-            ("referent", "referent_table"),
-        ]
-    )
     def create_foreign_key(
         cls,
         operations,
@@ -616,13 +534,6 @@ class CreateForeignKeyOp(AddConstraintOp):
         :param source_schema: Optional schema name of the source table.
         :param referent_schema: Optional schema name of the destination table.
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-           * source -> source_table
-           * referent -> referent_table
-
         """
 
         op = cls(
@@ -643,9 +554,6 @@ class CreateForeignKeyOp(AddConstraintOp):
         return operations.invoke(op)
 
     @classmethod
-    @util._with_legacy_names(
-        [("name", "constraint_name"), ("referent", "referent_table")]
-    )
     def batch_create_foreign_key(
         cls,
         operations,
@@ -678,12 +586,6 @@ class CreateForeignKeyOp(AddConstraintOp):
 
             :meth:`.Operations.create_foreign_key`
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-           * referent -> referent_table
-
         """
         op = cls(
             constraint_name,
@@ -716,19 +618,12 @@ class CreateCheckConstraintOp(AddConstraintOp):
     constraint_type = "check"
 
     def __init__(
-        self,
-        constraint_name,
-        table_name,
-        condition,
-        schema=None,
-        _orig_constraint=None,
-        **kw
+        self, constraint_name, table_name, condition, schema=None, **kw
     ):
         self.constraint_name = constraint_name
         self.table_name = table_name
         self.condition = condition
         self.schema = schema
-        self._orig_constraint = _orig_constraint
         self.kw = kw
 
     @classmethod
@@ -740,12 +635,10 @@ class CreateCheckConstraintOp(AddConstraintOp):
             constraint_table.name,
             constraint.sqltext,
             schema=constraint_table.schema,
-            _orig_constraint=constraint,
+            **constraint.dialect_kwargs
         )
 
     def to_constraint(self, migration_context=None):
-        if self._orig_constraint is not None:
-            return self._orig_constraint
         schema_obj = schemaobj.SchemaObjects(migration_context)
         return schema_obj.check_constraint(
             self.constraint_name,
@@ -756,9 +649,6 @@ class CreateCheckConstraintOp(AddConstraintOp):
         )
 
     @classmethod
-    @util._with_legacy_names(
-        [("name", "constraint_name"), ("source", "table_name")]
-    )
     def create_check_constraint(
         cls,
         operations,
@@ -807,21 +697,11 @@ class CreateCheckConstraintOp(AddConstraintOp):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-           * source -> table_name
-
         """
         op = cls(constraint_name, table_name, condition, schema=schema, **kw)
         return operations.invoke(op)
 
     @classmethod
-    @util._with_legacy_names([("name", "constraint_name")])
     def batch_create_check_constraint(
         cls, operations, constraint_name, condition, **kw
     ):
@@ -835,11 +715,6 @@ class CreateCheckConstraintOp(AddConstraintOp):
 
             :meth:`.Operations.create_check_constraint`
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> constraint_name
-
         """
         op = cls(
             constraint_name,
@@ -857,14 +732,7 @@ class CreateIndexOp(MigrateOperation):
     """Represent a create index operation."""
 
     def __init__(
-        self,
-        index_name,
-        table_name,
-        columns,
-        schema=None,
-        unique=False,
-        _orig_index=None,
-        **kw
+        self, index_name, table_name, columns, schema=None, unique=False, **kw
     ):
         self.index_name = index_name
         self.table_name = table_name
@@ -872,7 +740,6 @@ class CreateIndexOp(MigrateOperation):
         self.schema = schema
         self.unique = unique
         self.kw = kw
-        self._orig_index = _orig_index
 
     def reverse(self):
         return DropIndexOp.from_index(self.to_index())
@@ -888,15 +755,13 @@ class CreateIndexOp(MigrateOperation):
             sqla_compat._get_index_expressions(index),
             schema=index.table.schema,
             unique=index.unique,
-            _orig_index=index,
             **index.kwargs
         )
 
     def to_index(self, migration_context=None):
-        if self._orig_index:
-            return self._orig_index
         schema_obj = schemaobj.SchemaObjects(migration_context)
-        return schema_obj.index(
+
+        idx = schema_obj.index(
             self.index_name,
             self.table_name,
             self.columns,
@@ -904,9 +769,9 @@ class CreateIndexOp(MigrateOperation):
             unique=self.unique,
             **self.kw
         )
+        return idx
 
     @classmethod
-    @util._with_legacy_names([("name", "index_name")])
     def create_index(
         cls,
         operations,
@@ -932,12 +797,6 @@ class CreateIndexOp(MigrateOperation):
             from sqlalchemy import text
             op.create_index('ik_test', 't1', [text('lower(foo)')])
 
-        .. versionadded:: 0.6.7 support for making use of the
-           :func:`~sqlalchemy.sql.expression.text` construct in
-           conjunction with
-           :meth:`.Operations.create_index` in
-           order to produce functional expressions within CREATE INDEX.
-
         :param index_name: name of the index.
         :param table_name: name of the owning table.
         :param columns: a list consisting of string column names and/or
@@ -946,10 +805,6 @@ class CreateIndexOp(MigrateOperation):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         :param unique: If True, create a unique index.
 
         :param quote:
@@ -967,11 +822,6 @@ class CreateIndexOp(MigrateOperation):
             See the documentation regarding an individual dialect at
             :ref:`dialect_toplevel` for detail on documented arguments.
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> index_name
-
         """
         op = cls(
             index_name, table_name, columns, schema=schema, unique=unique, **kw
@@ -1005,23 +855,19 @@ class DropIndexOp(MigrateOperation):
     """Represent a drop index operation."""
 
     def __init__(
-        self, index_name, table_name=None, schema=None, _orig_index=None, **kw
+        self, index_name, table_name=None, schema=None, _reverse=None, **kw
     ):
         self.index_name = index_name
         self.table_name = table_name
         self.schema = schema
-        self._orig_index = _orig_index
+        self._reverse = _reverse
         self.kw = kw
 
     def to_diff_tuple(self):
         return ("remove_index", self.to_index())
 
     def reverse(self):
-        if self._orig_index is None:
-            raise ValueError(
-                "operation is not reversible; " "original index is not present"
-            )
-        return CreateIndexOp.from_index(self._orig_index)
+        return CreateIndexOp.from_index(self.to_index())
 
     @classmethod
     def from_index(cls, index):
@@ -1029,14 +875,11 @@ class DropIndexOp(MigrateOperation):
             index.name,
             index.table.name,
             schema=index.table.schema,
-            _orig_index=index,
+            _reverse=CreateIndexOp.from_index(index),
             **index.kwargs
         )
 
     def to_index(self, migration_context=None):
-        if self._orig_index is not None:
-            return self._orig_index
-
         schema_obj = schemaobj.SchemaObjects(migration_context)
 
         # need a dummy column name here since SQLAlchemy
@@ -1044,15 +887,12 @@ class DropIndexOp(MigrateOperation):
         return schema_obj.index(
             self.index_name,
             self.table_name,
-            ["x"],
+            self._reverse.columns if self._reverse else ["x"],
             schema=self.schema,
             **self.kw
         )
 
     @classmethod
-    @util._with_legacy_names(
-        [("name", "index_name"), ("tablename", "table_name")]
-    )
     def drop_index(
         cls, operations, index_name, table_name=None, schema=None, **kw
     ):
@@ -1070,30 +910,17 @@ class DropIndexOp(MigrateOperation):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         :param \**kw: Additional keyword arguments not mentioned above are
             dialect specific, and passed in the form
             ``<dialectname>_<argname>``.
             See the documentation regarding an individual dialect at
             :ref:`dialect_toplevel` for detail on documented arguments.
 
-            .. versionadded:: 0.9.5 Support for dialect-specific keyword
-               arguments for DROP INDEX
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> index_name
-
         """
         op = cls(index_name, table_name=table_name, schema=schema, **kw)
         return operations.invoke(op)
 
     @classmethod
-    @util._with_legacy_names([("name", "index_name")])
     def batch_drop_index(cls, operations, index_name, **kw):
         """Issue a "drop index" instruction using the
         current batch migration context.
@@ -1102,11 +929,6 @@ class DropIndexOp(MigrateOperation):
 
             :meth:`.Operations.drop_index`
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> index_name
-
         """
 
         op = cls(
@@ -1123,41 +945,52 @@ class CreateTableOp(MigrateOperation):
     """Represent a create table operation."""
 
     def __init__(
-        self, table_name, columns, schema=None, _orig_table=None, **kw
+        self, table_name, columns, schema=None, _namespace_metadata=None, **kw
     ):
         self.table_name = table_name
         self.columns = columns
         self.schema = schema
+        self.comment = kw.pop("comment", None)
+        self.prefixes = kw.pop("prefixes", None)
         self.kw = kw
-        self._orig_table = _orig_table
+        self._namespace_metadata = _namespace_metadata
 
     def reverse(self):
-        return DropTableOp.from_table(self.to_table())
+        return DropTableOp.from_table(
+            self.to_table(), _namespace_metadata=self._namespace_metadata
+        )
 
     def to_diff_tuple(self):
         return ("add_table", self.to_table())
 
     @classmethod
-    def from_table(cls, table):
+    def from_table(cls, table, _namespace_metadata=None):
+        if _namespace_metadata is None:
+            _namespace_metadata = table.metadata
+
         return cls(
             table.name,
             list(table.c) + list(table.constraints),
             schema=table.schema,
-            _orig_table=table,
+            _namespace_metadata=_namespace_metadata,
+            comment=table.comment,
+            prefixes=table._prefixes,
             **table.kwargs
         )
 
     def to_table(self, migration_context=None):
-        if self._orig_table is not None:
-            return self._orig_table
         schema_obj = schemaobj.SchemaObjects(migration_context)
 
         return schema_obj.table(
-            self.table_name, *self.columns, schema=self.schema, **self.kw
+            self.table_name,
+            *self.columns,
+            schema=self.schema,
+            prefixes=self.prefixes,
+            comment=self.comment,
+            **self.kw
         )
 
     @classmethod
-    @util._with_legacy_names([("name", "table_name")])
     def create_table(cls, operations, table_name, *columns, **kw):
         r"""Issue a "create table" instruction using the current migration
         context.
@@ -1218,8 +1051,6 @@ class CreateTableOp(MigrateOperation):
                 ]
             )
 
-        .. versionadded:: 0.7.0
-
         :param table_name: Name of the table
         :param \*columns: collection of :class:`~sqlalchemy.schema.Column`
          objects within
@@ -1230,23 +1061,12 @@ class CreateTableOp(MigrateOperation):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
         :param \**kw: Other keyword arguments are passed to the underlying
          :class:`sqlalchemy.schema.Table` object created for the command.
 
         :return: the :class:`~sqlalchemy.schema.Table` object corresponding
          to the parameters given.
 
-         .. versionadded:: 0.7.0 - the :class:`~sqlalchemy.schema.Table`
-            object is returned.
-
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> table_name
-
         """
         op = cls(table_name, columns, **kw)
         return operations.invoke(op)
@@ -1256,38 +1076,45 @@ class CreateTableOp(MigrateOperation):
 class DropTableOp(MigrateOperation):
     """Represent a drop table operation."""
 
-    def __init__(
-        self, table_name, schema=None, table_kw=None, _orig_table=None
-    ):
+    def __init__(self, table_name, schema=None, table_kw=None, _reverse=None):
         self.table_name = table_name
         self.schema = schema
         self.table_kw = table_kw or {}
-        self._orig_table = _orig_table
+        self._reverse = _reverse
 
     def to_diff_tuple(self):
         return ("remove_table", self.to_table())
 
     def reverse(self):
-        if self._orig_table is None:
-            raise ValueError(
-                "operation is not reversible; " "original table is not present"
-            )
-        return CreateTableOp.from_table(self._orig_table)
+        return CreateTableOp.from_table(self.to_table())
 
     @classmethod
-    def from_table(cls, table):
-        return cls(table.name, schema=table.schema, _orig_table=table)
-
-    def to_table(self, migration_context=None):
-        if self._orig_table is not None:
-            return self._orig_table
-        schema_obj = schemaobj.SchemaObjects(migration_context)
-        return schema_obj.table(
-            self.table_name, schema=self.schema, **self.table_kw
+    def from_table(cls, table, _namespace_metadata=None):
+        return cls(
+            table.name,
+            schema=table.schema,
+            table_kw=table.kwargs,
+            _reverse=CreateTableOp.from_table(
+                table, _namespace_metadata=_namespace_metadata
+            ),
         )
 
+    def to_table(self, migration_context=None):
+        if self._reverse:
+            cols_and_constraints = self._reverse.columns
+        else:
+            cols_and_constraints = []
+
+        schema_obj = schemaobj.SchemaObjects(migration_context)
+        t = schema_obj.table(
+            self.table_name,
+            *cols_and_constraints,
+            schema=self.schema,
+            **self.table_kw
+        )
+        return t
+
     @classmethod
-    @util._with_legacy_names([("name", "table_name")])
     def drop_table(cls, operations, table_name, schema=None, **kw):
         r"""Issue a "drop table" instruction using the current
         migration context.
@@ -1302,18 +1129,9 @@ class DropTableOp(MigrateOperation):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         :param \**kw: Other keyword arguments are passed to the underlying
          :class:`sqlalchemy.schema.Table` object created for the command.
 
-        .. versionchanged:: 0.8.0 The following positional argument names
-           have been changed:
-
-           * name -> table_name
-
         """
         op = cls(table_name, schema=schema, table_kw=kw)
         operations.invoke(op)
@@ -1348,18 +1166,17 @@ class RenameTableOp(AlterTableOp):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         """
         op = cls(old_table_name, new_table_name, schema=schema)
         return operations.invoke(op)
 
 
 @Operations.register_operation("create_table_comment")
+@BatchOperations.register_operation(
+    "create_table_comment", "batch_create_table_comment"
+)
 class CreateTableCommentOp(AlterTableOp):
-    """Represent a COMMENT ON `table` operation.
-    """
+    """Represent a COMMENT ON `table` operation."""
 
     def __init__(
         self, table_name, comment, schema=None, existing_comment=None
@@ -1406,9 +1223,37 @@ class CreateTableCommentOp(AlterTableOp):
         )
         return operations.invoke(op)
 
-    def reverse(self):
-        """Reverses the COMMENT ON operation against a table.
+    @classmethod
+    def batch_create_table_comment(
+        cls,
+        operations,
+        comment,
+        existing_comment=None,
+    ):
+        """Emit a COMMENT ON operation to set the comment for a table
+        using the current batch migration context.
+
+        .. versionadded:: 1.6.0
+
+        :param comment: string value of the comment being registered against
+         the specified table.
+        :param existing_comment: String value of a comment
+         already registered on the specified table, used within autogenerate
+         so that the operation is reversible, but not required for direct
+         use.
+
         """
+
+        op = cls(
+            operations.impl.table_name,
+            comment,
+            existing_comment=existing_comment,
+            schema=operations.impl.schema,
+        )
+        return operations.invoke(op)
+
+    def reverse(self):
+        """Reverses the COMMENT ON operation against a table."""
         if self.existing_comment is None:
             return DropTableCommentOp(
                 self.table_name,
@@ -1435,9 +1280,11 @@ class CreateTableCommentOp(AlterTableOp):
 
 
 @Operations.register_operation("drop_table_comment")
+@BatchOperations.register_operation(
+    "drop_table_comment", "batch_drop_table_comment"
+)
 class DropTableCommentOp(AlterTableOp):
-    """Represent an operation to remove the comment from a table.
-    """
+    """Represent an operation to remove the comment from a table."""
 
     def __init__(self, table_name, schema=None, existing_comment=None):
         self.table_name = table_name
@@ -1468,9 +1315,28 @@ class DropTableCommentOp(AlterTableOp):
         op = cls(table_name, existing_comment=existing_comment, schema=schema)
         return operations.invoke(op)
 
-    def reverse(self):
-        """Reverses the COMMENT ON operation against a table.
+    @classmethod
+    def batch_drop_table_comment(cls, operations, existing_comment=None):
+        """Issue a "drop table comment" operation to
+        remove an existing comment set on a table using the current
+        batch operations context.
+
+        .. versionadded:: 1.6.0
+
+        :param existing_comment: An optional string value of a comment already
+         registered on the specified table.
+
         """
+
+        op = cls(
+            operations.impl.table_name,
+            existing_comment=existing_comment,
+            schema=operations.impl.schema,
+        )
+        return operations.invoke(op)
+
+    def reverse(self):
+        """Reverses the COMMENT ON operation against a table."""
         return CreateTableCommentOp(
             self.table_name, self.existing_comment, schema=self.schema
         )
@@ -1647,7 +1513,6 @@ class AlterColumnOp(AlterTableOp):
         )
 
     @classmethod
-    @util._with_legacy_names([("name", "new_column_name")])
     def alter_column(
         cls,
         operations,
@@ -1746,18 +1611,12 @@ class AlterColumnOp(AlterTableOp):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         :param postgresql_using: String argument which will indicate a
          SQL expression to render within the Postgresql-specific USING clause
          within ALTER COLUMN.    This string is taken directly as raw SQL which
          must explicitly include any necessary quoting or escaping of tokens
          within the expression.
 
-         .. versionadded:: 0.8.8
-
         """
 
         alt = cls(
@@ -1919,10 +1778,6 @@ class AddColumnOp(AlterTableOp):
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
 
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
-
         """
 
         op = cls(table_name, column, schema=schema)
@@ -1962,12 +1817,12 @@ class DropColumnOp(AlterTableOp):
     """Represent a drop column operation."""
 
     def __init__(
-        self, table_name, column_name, schema=None, _orig_column=None, **kw
+        self, table_name, column_name, schema=None, _reverse=None, **kw
     ):
         super(DropColumnOp, self).__init__(table_name, schema=schema)
         self.column_name = column_name
         self.kw = kw
-        self._orig_column = _orig_column
+        self._reverse = _reverse
 
     def to_diff_tuple(self):
         return (
@@ -1978,23 +1833,28 @@ class DropColumnOp(AlterTableOp):
         )
 
     def reverse(self):
-        if self._orig_column is None:
+        if self._reverse is None:
             raise ValueError(
                 "operation is not reversible; "
                 "original column is not present"
             )
 
         return AddColumnOp.from_column_and_tablename(
-            self.schema, self.table_name, self._orig_column
+            self.schema, self.table_name, self._reverse.column
         )
 
     @classmethod
     def from_column_and_tablename(cls, schema, tname, col):
-        return cls(tname, col.name, schema=schema, _orig_column=col)
+        return cls(
+            tname,
+            col.name,
+            schema=schema,
+            _reverse=AddColumnOp.from_column_and_tablename(schema, tname, col),
+        )
 
     def to_column(self, migration_context=None):
-        if self._orig_column is not None:
-            return self._orig_column
+        if self._reverse is not None:
+            return self._reverse.column
         schema_obj = schemaobj.SchemaObjects(migration_context)
         return schema_obj.column(self.column_name, NULLTYPE)
 
@@ -2015,10 +1875,6 @@ class DropColumnOp(AlterTableOp):
          quoting of the schema outside of the default behavior, use
          the SQLAlchemy construct
          :class:`~sqlalchemy.sql.elements.quoted_name`.
-
-         .. versionadded:: 0.7.0 'schema' can now accept a
-            :class:`~sqlalchemy.sql.elements.quoted_name` construct.
-
         :param mssql_drop_check: Optional boolean.  When ``True``, on
          Microsoft SQL Server only, first
          drop the CHECK constraint on the column using a
@@ -2041,8 +1897,6 @@ class DropColumnOp(AlterTableOp):
          works if the column has exactly one FK constraint which refers to
          it, at the moment.
 
-         .. versionadded:: 0.6.2
-
         """
 
         op = cls(table_name, column_name, schema=schema, **kw)
@@ -2138,12 +1992,6 @@ class BulkInsertOp(MigrateOperation):
         still be rendered, rather than attempting to pass the values
         as bound parameters.
 
-        .. versionadded:: 0.6.4 :meth:`.Operations.inline_literal` can now
-           be used with :meth:`.Operations.bulk_insert`, and the
-           :paramref:`~.Operations.bulk_insert.multiinsert` flag has
-           been added to assist in this usage when running in "online"
-           mode.
-
         :param table: a table object which represents the target of the INSERT.
 
         :param rows: a list of dictionaries indicating rows.
@@ -2157,9 +2005,7 @@ class BulkInsertOp(MigrateOperation):
            in those cases where non-literal values are present in the
            parameter sets.
 
-           .. versionadded:: 0.6.4
-
-          """
+        """
 
         op = cls(table, rows, multiinsert=multiinsert)
         operations.invoke(op)
@@ -2360,11 +2206,6 @@ class MigrationScript(MigrateOperation):
     and ``.downgrade_ops_list`` list-based attributes.  These latter
     attributes are always available at the very least as single-element lists.
 
-    .. versionchanged:: 0.8.1 the ``.upgrade_ops`` and ``.downgrade_ops``
-       attributes should be accessed via the ``.upgrade_ops_list``
-       and ``.downgrade_ops_list`` attributes if multiple autogenerate
-       passes proceed on the same :class:`.MigrationScript` object.
-
     .. seealso::
 
         :ref:`customizing_revision`
@@ -2453,8 +2294,6 @@ class MigrationScript(MigrateOperation):
         attribute when dealing with a revision operation that does
         multiple autogenerate passes.
 
-        .. versionadded:: 0.8.1
-
         """
         return self._upgrade_ops
 
@@ -2466,7 +2305,5 @@ class MigrationScript(MigrateOperation):
         attribute when dealing with a revision operation that does
         multiple autogenerate passes.
 
-        .. versionadded:: 0.8.1
-
         """
         return self._downgrade_ops
