@@ -3,10 +3,8 @@ import inspect
 import io
 import sys
 
-py27 = sys.version_info >= (2, 7)
 py2k = sys.version_info.major < 3
 py3k = sys.version_info.major >= 3
-py35 = sys.version_info >= (3, 5)
 py36 = sys.version_info >= (3, 6)
 
 
@@ -88,11 +86,10 @@ if py3k:
 else:
     import collections as collections_abc  # noqa
 
-if py35:
+if py3k:
 
     def _formatannotation(annotation, base_module=None):
-        """vendored from python 3.7
-        """
+        """vendored from python 3.7"""
 
         if getattr(annotation, "__module__", None) == "typing":
             return repr(annotation).replace("typing.", "")
@@ -174,42 +171,22 @@ else:
 if py2k:
     from mako.util import parse_encoding
 
-if py35:
-    import importlib.util
-    import importlib.machinery
-
-    def load_module_py(module_id, path):
-        spec = importlib.util.spec_from_file_location(module_id, path)
-        module = importlib.util.module_from_spec(spec)
-        spec.loader.exec_module(module)
-        return module
-
-    def load_module_pyc(module_id, path):
-        spec = importlib.util.spec_from_file_location(module_id, path)
-        module = importlib.util.module_from_spec(spec)
-        spec.loader.exec_module(module)
-        return module
-
-
-elif py3k:
-    import importlib.machinery
-
-    def load_module_py(module_id, path):
-        module = importlib.machinery.SourceFileLoader(
-            module_id, path
-        ).load_module(module_id)
-        del sys.modules[module_id]
-        return module
-
-    def load_module_pyc(module_id, path):
-        module = importlib.machinery.SourcelessFileLoader(
-            module_id, path
-        ).load_module(module_id)
-        del sys.modules[module_id]
-        return module
-
-
 if py3k:
+    import importlib.machinery
+
+    import importlib.util
+
+    def load_module_py(module_id, path):
+        spec = importlib.util.spec_from_file_location(module_id, path)
+        module = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(module)
+        return module
+
+    def load_module_pyc(module_id, path):
+        spec = importlib.util.spec_from_file_location(module_id, path)
+        module = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(module)
+        return module
 
     def get_bytecode_suffixes():
         try:
@@ -218,7 +195,7 @@ if py3k:
             return importlib.machinery.DEBUG_BYTECODE_SUFFIXES
 
     def get_current_bytecode_suffixes():
-        if py35:
+        if py3k:
             suffixes = importlib.machinery.BYTECODE_SUFFIXES
         else:
             if sys.flags.optimize:
@@ -229,17 +206,7 @@ if py3k:
         return suffixes
 
     def has_pep3147():
-
-        if py35:
-            return True
-        else:
-            # TODO: not sure if we are supporting old versions of Python
-            # the import here emits a deprecation warning which the test
-            # suite only catches if imp wasn't imported alreadt
-            # http://www.python.org/dev/peps/pep-3147/#detecting-pep-3147-availability
-            import imp
-
-            return hasattr(imp, "get_tag")
+        return True
 
 
 else:
@@ -294,34 +261,54 @@ def with_metaclass(meta, base=object):
 
 if py3k:
 
-    def reraise(tp, value, tb=None, cause=None):
-        if cause is not None:
-            value.__cause__ = cause
-        if value.__traceback__ is not tb:
-            raise value.with_traceback(tb)
-        raise value
+    def raise_(
+        exception, with_traceback=None, replace_context=None, from_=False
+    ):
+        r"""implement "raise" with cause support.
 
-    def raise_from_cause(exception, exc_info=None):
-        if exc_info is None:
-            exc_info = sys.exc_info()
-        exc_type, exc_value, exc_tb = exc_info
-        reraise(type(exception), exception, tb=exc_tb, cause=exc_value)
+        :param exception: exception to raise
+        :param with_traceback: will call exception.with_traceback()
+        :param replace_context: an as-yet-unsupported feature.  This is
+         an exception object which we are "replacing", e.g., it's our
+         "cause" but we don't want it printed.    Basically just what
+         ``__suppress_context__`` does but we don't want to suppress
+         the enclosing context, if any.  So for now we make it the
+         cause.
+        :param from\_: the cause.  this actually sets the cause and doesn't
+         hope to hide it someday.
+
+        """
+        if with_traceback is not None:
+            exception = exception.with_traceback(with_traceback)
+
+        if from_ is not False:
+            exception.__cause__ = from_
+        elif replace_context is not None:
+            # no good solution here, we would like to have the exception
+            # have only the context of replace_context.__context__ so that the
+            # intermediary exception does not change, but we can't figure
+            # that out.
+            exception.__cause__ = replace_context
+
+        try:
+            raise exception
+        finally:
+            # credit to
+            # https://cosmicpercolator.com/2016/01/13/exception-leaks-in-python-2-and-3/
+            # as the __traceback__ object creates a cycle
+            del exception, replace_context, from_, with_traceback
 
 
 else:
     exec(
-        "def reraise(tp, value, tb=None, cause=None):\n"
-        "    raise tp, value, tb\n"
+        "def raise_(exception, with_traceback=None, replace_context=None, "
+        "from_=False):\n"
+        "    if with_traceback:\n"
+        "        raise type(exception), exception, with_traceback\n"
+        "    else:\n"
+        "        raise exception\n"
     )
 
-    def raise_from_cause(exception, exc_info=None):
-        # not as nice as that of Py3K, but at least preserves
-        # the code line where the issue occurred
-        if exc_info is None:
-            exc_info = sys.exc_info()
-        exc_type, exc_value, exc_tb = exc_info
-        reraise(type(exception), exception, tb=exc_tb)
-
 
 # produce a wrapper that allows encoded text to stream
 # into a given buffer, but doesn't close it.
